function spikes = lifouspikes( trials, input, tmaxdt, D, outau )
% Generate spike times of a leaky integrate-and-fire neuron
% trials: the number of trials to be generated
% input: the stimulus either as a single value or as a vector
% tmaxdt: in case of a single value stimulus the duration of a trial
%         in case of a vector as a stimulus the time step
% D: the strength of additive white noise
% outau: time constant of the colored noise
    
    tau = 0.01;
    if nargin < 4
        D = 1e0;
    end
    if nargin < 5
        outau = 1.0;
    end
    vreset = 0.0;
    vthresh = 10.0;
    dt = 1e-4;
    
    if length( input ) == 1
        input = input * ones( ceil( tmaxdt/dt ), 1 );
    else
        dt = tmaxdt;
    end
    spikes = cell( trials, 1 );
    for k=1:trials
        times = [];
        j = 1;
        n = 0.0;
        v = vreset;
        noise = sqrt(2.0*D)*randn( length( input ), 1 )/sqrt(dt);
        for i=1:length( noise )
            n = n + ( - n + noise(i))*dt/outau;
            v = v + ( - v + n + input(i))*dt/tau;
            if v >= vthresh
                v = vreset;
                times(j) = i*dt;
                j = j + 1;
            end
        end
        spikes{k} = times;
    end
end
