function spikes = lifboltzmanspikes( trials, input, tmaxdt, D, imax, ithresh, slope )
% Generate spike times of a leaky integrate-and-fire neuron
% trials: the number of trials to be generated
% input: the stimulus either as a single value or as a vector
% tmaxdt: in case of a single value stimulus the duration of a trial
%         in case of a vector as a stimulus the time step
% D: the strength of additive white noise
% imax: maximum output of boltzman
% ithresh: threshold of boltzman input
% slope: slope factor of boltzman input
    
    tau = 0.01;
    if nargin < 4
        D = 1e0;
    end
    if nargin < 5
        imax = 20;
    end
    if nargin < 6
        ithresh = 10;
    end
    if nargin < 7
        slope = 1;
    end
    vreset = 0.0;
    vthresh = 10.0;
    dt = 1e-4;
    
    if length( input ) == 1
        input = input * ones( ceil( tmaxdt/dt ), 1 );
    else
        dt = tmaxdt;
    end
    inb = imax./(1.0+exp(-slope.*(input - ithresh)));
    spikes = cell( trials, 1 );
    for k=1:trials
        times = [];
        j = 1;
        v = vreset;
        noise = sqrt(2.0*D)*randn( length( input ), 1 )/sqrt(dt);
        for i=1:length( noise )
            v = v + ( - v + noise(i) + inb(i))*dt/tau;
            if v >= vthresh
                v = vreset;
                times(j) = i*dt;
                j = j + 1;
            end
        end
        spikes{k} = times;
    end
end
